@@ -41,9 +41,10 @@ class Crawler:
     base_options = FirefoxOptions()
     base_options.headless = True
 
-    def __init__(self, url: str, remote: bool = False):
+    def __init__(self, url: str, remote: bool = False, debug: bool = False):
         self.url = url
         self.remote = remote
+        self.debug = debug
         self.driver = None
 
     def _init_driver(self) -> None:
@@ -52,6 +53,8 @@ class Crawler:
     def _get_driver(self) -> WebDriver:
         if self.remote:
             return webdriver.Remote(**self.remote_options, options=self.base_options)
+        if self.debug:
+            self.base_options.headless = False
         return webdriver.Firefox(options=self.base_options)
 
     def start(self) -> None:
@@ -61,7 +64,7 @@ class Crawler:
 
     def wait_element(self, selector: Selector, value: str) -> WebElement:
         # ждем появления и возвращаем элемент по типу селектора и значению
-        wait = WebDriverWait(self.driver, 10)
+        wait = WebDriverWait(self.driver, 20)
         try:
             return wait.until(EC.visibility_of_element_located((selector.value, value)))
         except TimeoutException:
@@ -96,10 +99,11 @@ def attempted_crawling(attempts: int):
                         TimeoutException,
                         AttributeError,
                         WebDriverException,
+                        exceptions.NotAuthorizeException,
                         ElementClickInterceptedException) as e:
                     logging.warning(e)
                     attempt += 1
-            raise exceptions.AmoCrawlerException
+            raise exceptions.FatalityException()
 
         return wrapper
 
@@ -121,10 +125,10 @@ class AmoPartnerCrawler(Crawler):
     CLASS FOR SCRAPING BILLING DATA FROM AMO PARTNER CABINET
     """
 
-    def __init__(self, email: str, password: str, remote: bool):
+    def __init__(self, email: str, password: str, remote: bool, debug: bool = False):
         self.email = email
         self.password = password
-        super().__init__(url='https://www.amocrm.ru/partners/private/shop/bill', remote=remote)
+        super().__init__(url='https://www.amocrm.ru/partners/private/shop/bill', remote=remote, debug=debug)
 
     @logg_func_execution
     def login(self, email: str, password: str) -> None:
@@ -154,11 +158,29 @@ class AmoPartnerCrawler(Crawler):
         except exceptions.ElementHiddenException:
             return True
 
+    @property
+    @logg_func_execution
+    def is_tech_account(self):
+        try:
+            self.unlock_screen()
+            tariff_select = self.wait_element(Selector.by_class_name, 'extend-tariff-list')
+            self.unlock_screen()
+            selected_tariff = tariff_select.get_attribute("value")
+            self.unlock_screen()
+            logging.warning(selected_tariff)
+        except exceptions.ElementHiddenException:
+            return False
+        if int(selected_tariff) == 22000000:
+            return True
+        return False
+
     @property
     @logg_func_execution
     def account_id_is_recognized(self):
         try:
+            self.unlock_screen()
             self.wait_element(Selector.by_class_name, 'bill_error')
+            self.unlock_screen()
             return False
         except exceptions.ElementHiddenException:
             return True
@@ -167,19 +189,25 @@ class AmoPartnerCrawler(Crawler):
     def fill_form(self, account_id: int) -> None:
         # заполнение биллинговой формы
         self.unlock_screen()
-        account_id_field = self.wait_element(Selector.by_name, 'account_id')
+        try:
+            account_id_field = self.wait_element(Selector.by_name, 'account_id')
+        except exceptions.ElementHiddenException:
+            raise exceptions.NotAuthorizeException()
         self.unlock_screen()
         account_id_field.send_keys(account_id)
-        self.wait(2)
+        self.unlock_screen()
+        if self.is_tech_account:
+            raise exceptions.TechAccountException()
+        self.wait(5)
+
         if not self.account_id_is_recognized:
             raise exceptions.IDNotFoundException()
         self.unlock_screen()
         currency_select_field = Select(self.wait_element(Selector.by_id, 'currency_id'))
-        logging.warning('3')
-        currency_select_field.select_by_value("RUB")
-
         self.unlock_screen()
-        self.wait(2)
+        currency_select_field.select_by_value("RUB")
+        self.unlock_screen()
+        self.wait(10)
         tariff_select_field = self.wait_element(Selector.by_id, 'tariff_id')
         # тариф иногда невозможно выбрать, стоит дефол
         if tariff_select_field.is_enabled():
@@ -187,8 +215,7 @@ class AmoPartnerCrawler(Crawler):
             tariff_select.select_by_value('19208542')
         self.unlock_screen()
         count_users_field = self.wait_element(Selector.by_id, 'col_users')
-        time.sleep(5)
-        logging.warning('5')
+        self.wait(5)
         count_users_field.send_keys(0)
         self.wait()
         period_to_pay_select_field = Select(self.wait_element(Selector.by_id, 'period_id'))
@@ -229,9 +256,13 @@ class AmoPartnerCrawler(Crawler):
     @attempted_crawling(attempts=3)
     def get_billing_data(self, account_id: int) -> schemas.BillingSchema:
         self.start()
+        logging.warning('START')
+        self.unlock_screen()
         # если не авторизованы - логинимся
         if not self.element_is_exists(Selector.by_id, 'user-select__header'):
+            self.unlock_screen()
             self.login(self.email, self.password)
+            self.unlock_screen()
         try:
             self.fill_form(account_id=account_id)
             self.approve_form()
@@ -241,6 +272,8 @@ class AmoPartnerCrawler(Crawler):
         except exceptions.BillingNotAvailableException:
             self.stop()
             return schemas.BillingSchema(is_paid=True)
-        except exceptions.IDNotFoundException:
+        except (exceptions.IDNotFoundException,
+                exceptions.FatalityException,
+                exceptions.TechAccountException):
             self.stop()
             return schemas.BillingSchema()
