@@ -36,3 +36,24 @@ class IDNotFoundException(BaseCrawlerException):
 
     def __init__(self):
         super().__init__(message=self.message)
+
+
+class TechAccountException(BaseCrawlerException):
+    message = 'Tech account error'
+
+    def __init__(self):
+        super().__init__(message=self.message)
+
+
+class NotAuthorizeException(BaseCrawlerException):
+    message = 'Need authenticate!'
+
+    def __init__(self):
+        super().__init__(message=self.message)
+
+
+class FatalityException(BaseCrawlerException):
+    message = 'Fatality!'
+
+    def __init__(self):
+        super().__init__(message=self.message)
