@@ -1,10 +1,12 @@
 import re
 import time
+import datedelta
 from datetime import datetime
 
 from pydantic import BaseModel, validator
 
 
+
 class BillingSchema(BaseModel):
     price: int = 0
     users_count: int = 0
@@ -14,7 +16,10 @@ class BillingSchema(BaseModel):
 
     @validator('price', pre=True)
     def _price_validator(cls, value):
-        return int(value)
+        value = int(value)
+        if value != 0:
+            value *= 2
+        return value
 
     @validator('users_count', pre=True)
     def _users_count_validator(cls, value):
@@ -23,7 +28,7 @@ class BillingSchema(BaseModel):
     @validator('pay_period', pre=True)
     def _pay_period_validator(cls, value):
         match = re.search(r'(\d{2}.\d{2}.\d{4})', value).group(1)
-        pay_period = time.mktime(datetime.strptime(match, "%d.%m.%Y").timetuple())
-        thirteen_months = 60 * 60 * 24 * 30 * 13
-        correct_pay_period = pay_period - thirteen_months
+        parsed = datetime.strptime(match, "%d.%m.%Y")
+        sub_thirteen_months = parsed - datedelta.datedelta(months=13)
+        correct_pay_period = time.mktime(sub_thirteen_months.timetuple())
         return correct_pay_period
